@@ -50,7 +50,7 @@ $example->Annotate(text=>'Magick',geometry=>'+0+20',font=>'@Generic.ttf',
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Blur');
-$example->Blur(3);
+$example->Blur('0.0x1.0');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Border');
@@ -58,7 +58,7 @@ $example->Border(color=>'gold');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Charcoal');
-$example->Charcoal(3);
+$example->Charcoal();
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Composite');
@@ -87,11 +87,11 @@ $example->Draw(stroke=>'gold',primitive=>'circle',points=>'60,90 60,120',
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Detect Edges');
-$example->Edge(3);
+$example->Edge();
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Emboss');
-$example->Emboss(3);
+$example->Emboss();
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Equalize');
@@ -99,7 +99,7 @@ $example->Equalize();
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Explode');
-$example->Set(background=>'#00000000');
+$example->Set(background=>'#000000FF');
 $example->Implode(-10);
 push(@$images,$example);
 $example=$model->Clone();
@@ -120,14 +120,14 @@ $example->Gamma(1.6);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Gaussian Blur');
-$example->GaussianBlur("2x2");
+$example->GaussianBlur('0.0x1.5');
 push(@$images,$example);
-$gradation=Image::Magick->new;
-$gradation->Set(size=>'130x194');
-$x=$gradation->ReadImage('gradation:#20a0ff-#ffff00');
+$gradient=Image::Magick->new;
+$gradient->Set(size=>'130x194');
+$x=$gradient->ReadImage('gradient:#20a0ff-#ffff00');
 warn "$x" if "$x";
-$gradation->Label('Gradation');
-push(@$images,$gradation);
+$gradient->Label('Gradient');
+push(@$images,$gradient);
 $example=$model->Clone();
 $example->Label('Grayscale');
 $example->Quantize(colorspace=>'gray');
@@ -142,7 +142,7 @@ $example->MedianFilter();
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Modulate');
-$example->Modulate(brightness=>-3,saturation=>-3,hue=>-3);
+$example->Modulate(brightness=>110,saturation=>110,hue=>110);
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Monochrome');
@@ -172,7 +172,11 @@ $example->Raise();
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Reduce Noise');
-$example->ReduceNoise(order=>3);
+$example->ReduceNoise();
+push(@$images,$example);
+$example=$model->Clone();
+$example->Label('Resize');
+$example->Resize('50%');
 push(@$images,$example);
 $example=$model->Clone();
 $example=$model->Clone();
@@ -198,7 +202,7 @@ $example->Shade(geometry=>'30x30',color=>'false');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Sharpen');
-$example->Sharpen(3);
+$example->Sharpen('0.0x1.0');
 push(@$images,$example);
 $example=$model->Clone();
 $example->Label('Shear');
@@ -214,18 +218,18 @@ $example->Label('Solarize');
 $example->Solarize();
 push(@$images,$example);
 $example=$model->Clone();
-$example->Set(background=>'#00000000');
+$example->Set(background=>'#000000FF');
 $example->Label('Swirl');
 $example->Swirl(90);
 push(@$images,$example);
 $example=$model->Clone();
-$example->Label('Wave');
-$example->Set(background=>'#00000000');
-$example->Wave('25x150');
+$example->Label('Unsharp Mask');
+$example->UnsharpMask('0.0x1.0');
 push(@$images,$example);
 $example=$model->Clone();
-$example->Label('Zoom');
-$example->Zoom('50%');
+$example->Label('Wave');
+$example->Set(background=>'#000000FF');
+$example->Wave('25x150');
 push(@$images,$example);
 #
 # Create image montage.
